#!/bin/sh

MAKEDEPS=""
DEPS="libxml2"

PKG_VER=5.1
SOURCE=https://docbook.org/xml/$PKG_VER/docbook-v$PKG_VER-os.zip
DESC="A widely used XML scheme for writing documentation and help"

package () {
    install -dm755 $PKG_DEST/usr/share/xml/docbook/schema/sch/$PKG_VER         &&
    install -dm755 $PKG_DEST/usr/share/xml/docbook/schema/rng/$PKG_VER         &&
    install -m644   schemas/rng/* $PKG_DEST/usr/share/xml/docbook/schema/rng/$PKG_VER &&
    install -m644   schemas/sch/* $PKG_DEST/usr/share/xml/docbook/schema/sch/$PKG_VER &&
    install -m755   tools/db4-entities.pl $PKG_DEST/usr/bin                      &&
    install -dm755 $PKG_DEST/usr/share/xml/docbook/stylesheet/docbook5          &&
    install -m644   tools/db4-upgrade.xsl \
                    $PKG_DEST/usr/share/xml/docbook/stylesheet/docbook5
} 

postinstall () {
    mkdir -p /etc/xml
    if [ ! -e /etc/xml/docbook-$PKG_VER ]; then
      xmlcatalog --noout --create /etc/xml/docbook-$PKG_VER
    fi &&

    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/rng/docbook.rng" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbook.rng" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/rng/docbook.rng" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbook.rng" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/rng/docbookxi.rng" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbookxi.rng" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/rng/docbookxi.rng" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbookxi.rng" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/rnc/docbook.rnc" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbook.rnc" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/rng/docbook.rnc" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbook.rnc" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/rnc/docbookxi.rnc" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbookxi.rnc" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/rng/docbookxi.rnc" \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/docbookxi.rnc" \
      /etc/xml/docbook-$PKG_VER &&

    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/sch/docbook.sch" \
      "file:///usr/share/xml/docbook/schema/sch/$PKG_VER/docbook.sch" \
      /etc/xml/docbook-$PKG_VER &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/sch/docbook.sch" \
      "file:///usr/share/xml/docbook/schema/sch/$PKG_VER/docbook.sch" \
      /etc/xml/docbook-$PKG_VER

    xmlcatalog --noout --create /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&

    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/schemas/rng/docbook.schemas/rng" \
      "docbook.schemas/rng" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/schemas/rng/docbook.schemas/rng" \
      "docbook.schemas/rng" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/schemas/rng/docbookxi.schemas/rng" \
      "docbookxi.schemas/rng" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/schemas/rng/docbookxi.schemas/rng" \
      "docbookxi.schemas/rng" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/schemas/rng/docbook.rnc" \
      "docbook.rnc" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/schemas/rng/docbook.rnc" \
      "docbook.rnc" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/schemas/rng/docbookxi.rnc" \
      "docbookxi.rnc" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/schemas/rng/docbookxi.rnc" \
      "docbookxi.rnc" /usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml
    xmlcatalog --noout --create /usr/share/xml/docbook/schema/sch/$PKG_VER/catalog.xml &&

    xmlcatalog --noout --add "uri" \
      "http://docbook.org/xml/$PKG_VER/schemas/sch/docbook.schemas/sch" \
      "docbook.schemas/sch" /usr/share/xml/docbook/schema/sch/$PKG_VER/catalog.xml &&
    xmlcatalog --noout --add "uri" \
      "http://www.oasis-open.org/docbook/xml/$PKG_VER/schemas/sch/docbook.schemas/sch" \
      "docbook.schemas/sch" /usr/share/xml/docbook/schema/sch/$PKG_VER/catalog.xml

    if [ ! -e /etc/xml/catalog ]; then
      xmlcatalog --noout --create /etc/xml/catalog
    fi &&
    xmlcatalog --noout --add "delegatePublic" \
      "-//OASIS//DTD DocBook XML $PKG_VER//EN" \
      "file:///usr/share/xml/docbook/schema/dtd/$PKG_VER/catalog.xml" \
      /etc/xml/catalog &&
    xmlcatalog --noout --add "delegateSystem" \
      "http://docbook.org/xml/$PKG_VER/dtd/" \
      "file:///usr/share/xml/docbook/schema/dtd/$PKG_VER/catalog.xml" \
      /etc/xml/catalog &&
    xmlcatalog --noout --add "delegateURI" \
      "http://docbook.org/xml/$PKG_VER/dtd/" \
      "file:///usr/share/xml/docbook/schema/dtd/$PKG_VER/catalog.xml" \
      /etc/xml/catalog &&
    xmlcatalog --noout --add "delegateURI" \
      "http://docbook.org/xml/$PKG_VER/rng/"  \
      "file:///usr/share/xml/docbook/schema/rng/$PKG_VER/catalog.xml" \
      /etc/xml/catalog &&
    xmlcatalog --noout --add "delegateURI" \
      "http://docbook.org/xml/$PKG_VER/sch/"  \
      "file:///usr/share/xml/docbook/schema/sch/$PKG_VER/catalog.xml" \
      /etc/xml/catalog &&
    xmlcatalog --noout --add "delegateURI" \
      "http://docbook.org/xml/$PKG_VER/xsd/"  \
      "file:///usr/share/xml/docbook/schema/xsd/$PKG_VER/catalog.xml" \
      /etc/xml/catalog
}


postinstall
